@@ -1201,7 +1201,7 @@ EOF
     SignatureManager.new do |manager|
       manager.files[Pathname("foo.rbs")] = <<EOF
 class Hello[A]
-  def initialize: [A] () { (A) -> void } -> void
+  def initialize: [A] (A) { (A) -> void } -> void
 end
 EOF
 
@@ -1211,7 +1211,7 @@ EOF
         builder.build_instance(type_name("::Hello")).yield_self do |definition|
           assert_instance_of Definition, definition
 
-          assert_method_definition definition.methods[:initialize], ["[A] () { (A) -> void } -> void"]
+          assert_method_definition definition.methods[:initialize], ["[A] (A) { (A) -> void } -> void"]
         end
 
         builder.build_singleton(type_name("::Hello")).yield_self do |definition|
@@ -1221,8 +1221,8 @@ EOF
             assert_instance_of Definition::Method, method
 
             assert_equal 1, method.method_types.size
-            # [A, A@1] () { (A@1) -> void } -> ::Hello[A]
-            assert_match(/\A\[A, A@(\d+)\] \(\) { \(A@\1\) -> void } -> ::Hello\[A\]\Z/, method.method_types[0].to_s)
+            # [A, A@1] (A@1) { (A@1) -> void } -> ::Hello[A]
+            assert_match(/\A\[A, A@(\d+)\] \(A@\1\) { \(A@\1\) -> void } -> ::Hello\[A\]\Z/, method.method_types[0].to_s)
           end
         end
       end
@@ -1969,4 +1969,198 @@ end
       end
     end
   end
+
+  def test_expand_alias2
+    SignatureManager.new do |manager|
+      manager.files.merge!(Pathname("foo.rbs") => <<-EOF)
+type opt[T] = T | nil
+type pair[S, T] = [S, T]
+      EOF
+
+      manager.build do |env|
+        builder = DefinitionBuilder.new(env: env)
+
+        assert_equal(
+          parse_type("::Integer | nil"),
+          builder.expand_alias2(type_name("::opt"), [parse_type("::Integer")])
+        )
+
+        assert_equal(
+          parse_type("[::String, bool]"),
+          builder.expand_alias2(type_name("::pair"), [parse_type("::String"), parse_type("bool")])
+        )
+
+        assert_raises do
+          builder.expand_alias2(type_name("::opt"), [])
+        end
+
+        assert_raises do
+          builder.expand_alias2(type_name("::opt"), [parse_type("bool"), parse_type("top")])
+        end
+end
+    end
+  end
+
+  def test_singleton_public_private
+    SignatureManager.new do |manager|
+      manager.files.merge!(Pathname("foo.rbs") => <<-EOF)
+class C
+  private
+  def self.a: () -> void
+end
+
+module M
+  private
+  def self.b: () -> void
+end
+      EOF
+      manager.build do |env|
+        builder = DefinitionBuilder.new(env: env)
+
+        builder.build_singleton(type_name("::C")).tap do |definition|
+          definition.methods[:a].tap do |a|
+            assert_predicate a, :public?
+          end
+        end
+
+        builder.build_singleton(type_name("::M")).tap do |definition|
+          definition.methods[:b].tap do |b|
+            assert_predicate b, :public?
+          end
+        end
+      end
+    end
+  end
+
+  def test_module_function
+    SignatureManager.new do |manager|
+      manager.files.merge!(Pathname("foo.rbs") => <<-EOF)
+class C
+  def self?.a: () -> void
+end
+
+module M
+  def self?.b: () -> void
+end
+      EOF
+      manager.build do |env|
+        builder = DefinitionBuilder.new(env: env)
+
+        builder.build_singleton(type_name("::C")).tap do |definition|
+          definition.methods[:a].tap do |a|
+            assert_predicate a, :public?
+          end
+        end
+
+        builder.build_instance(type_name("::C")).tap do |definition|
+          definition.methods[:a].tap do |a|
+            assert_predicate a, :private?
+          end
+        end
+
+        builder.build_singleton(type_name("::M")).tap do |definition|
+          definition.methods[:b].tap do |b|
+            assert_predicate b, :public?
+          end
+        end
+
+        builder.build_instance(type_name("::M")).tap do |definition|
+          definition.methods[:b].tap do |b|
+            assert_predicate b, :private?
+          end
+        end
+      end
+    end
+  end
+
+  def test_alias_visibility
+    SignatureManager.new do |manager|
+      manager.files.merge!(Pathname("foo.rbs") => <<-EOF)
+class C
+  def self?.a: () -> void
+
+  public
+
+  alias b a
+end
+      EOF
+      manager.build do |env|
+        builder = DefinitionBuilder.new(env: env)
+
+        builder.build_instance(type_name("::C")).tap do |definition|
+          definition.methods[:a].tap do |a|
+            assert_predicate a, :private?
+          end
+
+          definition.methods[:b].tap do |b|
+            assert_predicate b, :private?
+          end
+        end
+      end
+    end
+  end
+
+  def test_def_with_visibility_modifier
+    SignatureManager.new do |manager|
+      manager.files.merge!(Pathname("foo.rbs") => <<-EOF)
+class C
+  private def self.a: () -> void
+end
+
+module M
+  private
+  public def b: () -> void
+end
+      EOF
+      manager.build do |env|
+        builder = DefinitionBuilder.new(env: env)
+
+        builder.build_singleton(type_name("::C")).tap do |definition|
+          definition.methods[:a].tap do |a|
+            assert_predicate a, :private?
+          end
+        end
+
+        builder.build_instance(type_name("::M")).tap do |definition|
+          definition.methods[:b].tap do |b|
+            assert_predicate b, :public?
+          end
+        end
+      end
+    end
+  end
+
+  def test_attribute_with_visibility_modifier
+    SignatureManager.new do |manager|
+      manager.files.merge!(Pathname("foo.rbs") => <<-EOF)
+class C
+  private attr_reader self.a: String
+end
+
+module M
+  private
+  public attr_accessor b: String
+end
+      EOF
+      manager.build do |env|
+        builder = DefinitionBuilder.new(env: env)
+
+        builder.build_singleton(type_name("::C")).tap do |definition|
+          definition.methods[:a].tap do |a|
+            assert_predicate a, :private?
+          end
+        end
+
+        builder.build_instance(type_name("::M")).tap do |definition|
+          definition.methods[:b].tap do |b|
+            assert_predicate b, :public?
+          end
+
+          definition.methods[:b=].tap do |b|
+            assert_predicate b, :public?
+          end
+        end
+      end
+    end
+  end
 end
