@@ -189,7 +189,7 @@ EOF
       entry.insert(decl: decls[0], outer: [])
       entry.insert(decl: decls[1], outer: [])
 
-      assert_instance_of RBS::AST::Declarations::ModuleTypeParams, entry.type_params
+      assert_instance_of Array, entry.type_params
     end
 
     Environment::ModuleEntry.new(name: type_name("::Foo")).tap do |entry|
@@ -307,8 +307,6 @@ module Foo : _Each[String]
 
   type t = ::String | String
 
-  $size: Integer
-
   class String
   end
 
@@ -366,8 +364,6 @@ module ::Foo : ::Foo::_Each[::Foo::String]
 
   type ::Foo::t = ::String | ::Foo::String
 
-  $size: Integer
-
   class ::Foo::String
   end
 
@@ -388,6 +384,31 @@ end
 RBS
   end
 
+  def test_absolute_type_super
+    env = Environment.new
+
+    decls = RBS::Parser.parse_signature(<<-RBS)
+module A
+  class C
+  end
+
+  class B < C
+    class C
+    end
+  end
+end
+    RBS
+
+    decls.each do |decl|
+      env << decl
+    end
+
+    env.resolve_type_names.tap do |env|
+      class_decl = env.class_decls[TypeName("::A::B")]
+      assert_equal TypeName("::A::C"), class_decl.primary.decl.super_class.name
+    end
+  end
+
   def test_reject
     env = Environment.new
 
@@ -421,4 +442,44 @@ EOF
     assert env_.buffers.none? {|buf| buf.name == Pathname("foo.rbs") }
     assert env_.buffers.any? {|buf| buf.name == Pathname("bar.rbs") }
   end
+
+  def test_absolute_type_generics_upper_bound
+    env = Environment.new
+
+    decls = RBS::Parser.parse_signature(<<RBS)
+interface _Equatable
+  def ==: (untyped) -> bool
+end
+
+module Bar[A]
+end
+
+class Foo[A < _Equatable]
+  def test: [B < Bar[_Equatable]] (A, B) -> bool
+end
+RBS
+
+    decls.each do |decl|
+      env << decl
+    end
+
+    env_ = env.resolve_type_names
+
+    writer = RBS::Writer.new(out: StringIO.new)
+
+    writer.write(env_.declarations)
+
+    assert_equal(<<RBS, writer.out.string)
+interface ::_Equatable
+  def ==: (untyped) -> bool
+end
+
+module ::Bar[A]
+end
+
+class ::Foo[A < ::_Equatable]
+  def test: [B < ::Bar[::_Equatable]] (A, B) -> bool
+end
+RBS
+  end
 end
