@@ -15,13 +15,6 @@ class RBS::TypeParsingTest < Test::Unit::TestCase
       assert_equal "void", type.location.source
     end
 
-    silence_warnings do
-      Parser.parse_type("any").yield_self do |type|
-        assert_instance_of Types::Bases::Any, type
-        assert_equal "any", type.location.source
-      end
-    end
-
     Parser.parse_type("untyped").yield_self do |type|
       assert_instance_of Types::Bases::Any, type
       assert_equal "untyped", type.location.source
@@ -61,6 +54,11 @@ class RBS::TypeParsingTest < Test::Unit::TestCase
       assert_instance_of Types::Bases::Class, type
       assert_equal "class", type.location.source
     end
+
+    Parser.parse_type("any").yield_self do |type|
+      assert_instance_of Types::Alias, type
+      assert_equal "any", type.location.source
+    end
   end
 
   def test_instance
@@ -125,8 +123,12 @@ class RBS::TypeParsingTest < Test::Unit::TestCase
       assert_equal "::Foo::foo", type.location.source
     end
 
-    assert_raises Parser::SyntaxError do
-      Parser.parse_type("foo[untyped]")
+    Parser.parse_type("foo[untyped]").yield_self do |type|
+      assert_instance_of Types::Alias, type
+      assert_equal TypeName.new(namespace: Namespace.empty, name: :foo), type.name
+      assert_equal "foo[untyped]", type.location.source
+      assert_equal "foo", type.location[:name].source
+      assert_equal "[untyped]", type.location[:args].source
     end
   end
 
@@ -261,11 +263,11 @@ class RBS::TypeParsingTest < Test::Unit::TestCase
       assert_equal "singleton(::Object)", type.location.source
     end
 
-    assert_raises Parser::SyntaxError do
+    assert_raises RBS::ParsingError do
       Parser.parse_type("singleton(foo)")
     end
 
-    assert_raises Parser::SyntaxError do
+    assert_raises RBS::ParsingError do
       Parser.parse_type("singleton(_FOO)")
     end
   end
@@ -314,7 +316,7 @@ class RBS::TypeParsingTest < Test::Unit::TestCase
       assert_equal "^(untyped, void) -> void", type.location.source
     end
 
-    Parser.parse_type("^(untyped x, void _y) -> void").yield_self do |type|
+    Parser.parse_type("^(untyped x, void _y, bool `type`) -> void").yield_self do |type|
       assert_instance_of Types::Proc, type
 
       fun = type.type
@@ -322,6 +324,7 @@ class RBS::TypeParsingTest < Test::Unit::TestCase
       assert_equal [
                      Types::Function::Param.new(type: Types::Bases::Any.new(location: nil), name: :x),
                      Types::Function::Param.new(type: Types::Bases::Void.new(location: nil), name: :_y),
+                     Types::Function::Param.new(type: Types::Bases::Bool.new(location: nil), name: :type),
                    ], fun.required_positionals
       assert_equal [], fun.optional_positionals
       assert_nil fun.rest_positionals
@@ -330,7 +333,7 @@ class RBS::TypeParsingTest < Test::Unit::TestCase
       assert_equal({}, fun.optional_keywords)
       assert_nil fun.rest_keywords
 
-      assert_equal "^(untyped x, void _y) -> void", type.location.source
+      assert_equal "^(untyped x, void _y, bool `type`) -> void", type.location.source
     end
 
     Parser.parse_type("^(untyped x, ?void, ?nil y) -> void").yield_self do |type|
@@ -545,11 +548,11 @@ class RBS::TypeParsingTest < Test::Unit::TestCase
       end
     end
 
-    assert_raises Parser::SyntaxError do
+    assert_raises RBS::ParsingError do
       Parser.parse_type(":+foo")
     end
 
-    assert_raises Parser::SyntaxError do
+    assert_raises RBS::ParsingError do
       Parser.parse_type(":@")
     end
 
@@ -611,10 +614,11 @@ class RBS::TypeParsingTest < Test::Unit::TestCase
       assert_equal 1, type.args.size
       type.args[0].yield_self do |arg|
         assert_instance_of Types::Variable, arg
+        assert_instance_of RBS::Location, arg.location
       end
     end
 
-    assert_raises Parser::SemanticsError do
+    assert_raises RBS::ParsingError do
       Parser.parse_type("Array[A]", variables: [:A, :Array])
     end
   end
@@ -637,42 +641,42 @@ class RBS::TypeParsingTest < Test::Unit::TestCase
 
   def test_location_children
     Parser.parse_type("_Foo").yield_self do |type|
-      assert_instance_of RBS::Location::WithChildren, type.location
+      assert_instance_of RBS::Location, type.location
 
       assert_equal "_Foo", type.location[:name].source
       assert_nil type.location[:args]
     end
 
     Parser.parse_type("_Foo[untyped]").yield_self do |type|
-      assert_instance_of RBS::Location::WithChildren, type.location
+      assert_instance_of RBS::Location, type.location
 
       assert_equal "_Foo", type.location[:name].source
       assert_equal "[untyped]", type.location[:args].source
     end
 
     Parser.parse_type("Foo").yield_self do |type|
-      assert_instance_of RBS::Location::WithChildren, type.location
+      assert_instance_of RBS::Location, type.location
 
       assert_equal "Foo", type.location[:name].source
       assert_nil type.location[:args]
     end
 
     Parser.parse_type("Foo[untyped]").yield_self do |type|
-      assert_instance_of RBS::Location::WithChildren, type.location
+      assert_instance_of RBS::Location, type.location
 
       assert_equal "Foo", type.location[:name].source
       assert_equal "[untyped]", type.location[:args].source
     end
 
     Parser.parse_type("foo").yield_self do |type|
-      assert_instance_of RBS::Location::WithChildren, type.location
+      assert_instance_of RBS::Location, type.location
 
       assert_equal "foo", type.location[:name].source
       assert_nil type.location[:args]
     end
 
     Parser.parse_type("singleton(::Foo)").yield_self do |type|
-      assert_instance_of RBS::Location::WithChildren, type.location
+      assert_instance_of RBS::Location, type.location
 
       assert_equal "::Foo", type.location[:name].source
     end
