@@ -799,8 +799,10 @@ class OpenSSLECTest < Test::Unit::TestCase
   testing "::OpenSSL::PKey::EC"
 
   def test_dh_compute_key
-    assert_send_type "(OpenSSL::PKey::EC::Point) -> String",
+    assert_send_type(
+      "(OpenSSL::PKey::EC::Point) -> String",
       pkey, :dh_compute_key, OpenSSL::PKey::EC.generate("prime256v1").public_key
+    )
   end
 
   def test_dsa_sign_verify_asn1
@@ -1083,4 +1085,4 @@ class OpenSSLX509NameTest < Test::Unit::TestCase
   def name
     OpenSSL::X509::Name.parse('/CN=nobody/DC=example')
   end
-end
\ No newline at end of file
+end
